pub struct ObservedWebViewState {
pub url: Option<String>,
pub title: Option<String>,
pub favicon_png: Option<Vec<u8>>,
pub can_go_back: bool,
pub can_go_forward: bool,
}Expand description
Fold of WebViewStateChange into the current observed state, including
the None-clears semantics, so all consumers interpret clearing the same
way.
Fields
url: Option<String>title: Option<String>favicon_png: Option<Vec<u8>>can_go_back: boolcan_go_forward: boolImplementations
Sourceimpl ObservedWebViewState
impl ObservedWebViewState
Sourcepub fn apply(&mut self, change: WebViewStateChange)
pub fn apply(&mut self, change: WebViewStateChange)
Fold one change into the state. Takes the change by value so owned payloads are retained without cloning.