pub struct NativeWebViewId(/* private fields */);Expand description
Opaque identity for one native WebView instance.
A crate::WebTag is a logical lookup key and may be reused after a
WebView is destroyed. This identity is allocated for one concrete native
instance and is therefore the only identity suitable for message binding.