pub struct WebResourceResponse { /* private fields */ }Expand description
Represents an HTTP response whose body is provided by a file path, pipe, or in-memory bytes.
Implementations
Sourceimpl WebResourceResponse
impl WebResourceResponse
Sourcepub fn into_parts(self) -> (Parts, WebResourceBody)
pub fn into_parts(self) -> (Parts, WebResourceBody)
Consume the struct and return the owned parts and file path.
Sourceimpl WebResourceResponse
impl WebResourceResponse
Sourcepub fn file(path: impl Into<PathBuf>) -> Self
pub fn file(path: impl Into<PathBuf>) -> Self
Create a response serving a file from disk (status 200).
Sourcepub fn bytes(data: impl Into<Vec<u8>>) -> Self
pub fn bytes(data: impl Into<Vec<u8>>) -> Self
Create a response serving in-memory bytes (status 200).
Sourcepub fn stream(reader: SystemPipeReader) -> Self
pub fn stream(reader: SystemPipeReader) -> Self
Create a response serving data from a system pipe (status 200).