pub trait DocumentOutboundGate: Send + Sync {
// Required method
fn with_active(&self, action: &mut dyn FnMut()) -> bool;
}Expand description
A document-session authority check for one outbound native message.
Implementations must invoke action only while the document session is
still active. The closure makes it possible for a registry-backed gate to
keep its lock for the check and the native post as one operation.
Required Methods
fn with_active(&self, action: &mut dyn FnMut()) -> bool
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".